# Jupyter kernels for the Spyder console

Package that provides the kernels used by Spyder on its IPython console.

## Installation

To install this plugin, you can use either the ``pip`` or ``conda`` package
managers, as follows:

Using conda (the recommended way!):

```
conda install spyder-kernels
```

Using pip:

```
pip install spyder-kernels
```

## Dependencies

This project depends on:

* [ipykernel](https://github.com/ipython/ipykernel/)
* [cloudpickle](https://github.com/cloudpipe/cloudpickle)


## Changelog
Visit our [CHANGELOG](CHANGELOG.md) file to know more about our new features
and improvements.

## Development and contribution
To start contributing to this project you can execute ``python setup.py install``
to test your changes on Spyder. We follow PEP8 and PEP257 style guidelines.
